@@ -21,16 +21,16 @@
 
 #include "toplevel.h"
 
-#include <qapplication.h>
+#include <QApplication>
 #include <KLocalizedString>
 
 #include <KAboutData>
 #include <KCrash>
-#include <kmessagebox.h>
-#include <qtimer.h>
+#include <KMessageBox>
+#include <QTimer>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 #include <KDBusService>
 #include "levelset.h"
 #include "katomic_version.h"
@@ -44,6 +44,8 @@ I18N_NOOP("KDE Atomic Entertainment Game");
 
 int main(int argc, char **argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("katomic"));
